==> qcake_0.6.3.orig.tar.gz: qcake-0.6.3/src/spl_prg.hpp <==
/***************************************************************************
                          spl_prg.hpp  -  description
                             -------------------
    begin                : Fri Jan 21 2005
    copyright            : (C) 2005 by Harald Krippel
    email                : neuro.harald@surfeu.at
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPL_PRG_H
#define SPL_PRG_H

/**
class for spl scripting implementation

	@author Harald Krippel, Clifford Wolf
*/

#include <QtGui>

#include "globdefines.h"
#include <spl.h>
#include "scriptprg.hpp"

class FolderListItem;
class QcakeScriptApi;

class splPrg : public scriptPrg
{
  Q_OBJECT

   public:
     splPrg(const char *prg);

     int compile(void);
     void update(void);
     ~splPrg(void);

   public:

  struct spl_task *task;
  struct spl_asm *as;
  char *spl_source;
  char  prgname[512];
  char  prgsrc[512];
  FolderListItem *item;
  QcakeScriptApi *ScriptApi;

protected:
  struct spl_vm *vm;
};

#endif // SPL_PRG_H

==> qcake_0.7.0.orig.tar.gz: qcake-0.7.0/src/spl_prg.hpp <==
/***************************************************************************
                          spl_prg.hpp  -  description
                             -------------------
    begin                : Fri Jan 21 2005
    copyright            : (C) 2005 by Harald Krippel
    email                : harald@hte-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPL_PRG_H
#define SPL_PRG_H

/**
class for spl scripting implementation

	@author Harald Krippel, Clifford Wolf
*/

#include <QtGui>

#include "globdefines.h"
#include <spl.h>
#include "scriptprg.hpp"

class FolderListItem;
class QcakeScriptApi;

class splPrg : public scriptPrg
{
  Q_OBJECT

   public:
     splPrg(const char *prg);

     int compile(void);
     void update(void);
     ~splPrg(void);

   public:

  struct spl_task *task;
  struct spl_asm *as;
  char *spl_source;
  char  prgname[512];
  char  prgsrc[512];
  QcakeScriptApi *ScriptApi;

protected:
  struct spl_vm *vm;
};

#endif // SPL_PRG_H
